@@ -3,9 +3,6 @@
 # Created on Thu Jun 11 2020
 # Copyright (c) 2020 Moritz Wolter
 #
-import os
-
-import click
 import jax.numpy as np
 
 default_x0 = np.array([2.0, 1.0, 3.0])
@@ -17,8 +14,8 @@ def generate_lorenz(
     c: float = 8.0 / 3.0,
     dt: float = 0.01,
     tmax: float = 5.11,
-    x0: np.array = default_x0,
-):
+    x0: np.ndarray = default_x0,
+) -> np.ndarray:
     """Generate test data using the lorenz-system.
 
     The implementation follows the description at:
@@ -39,7 +36,7 @@ def generate_lorenz(
     steps = tmax / dt
     x_lst = []
 
-    def compute_dx_dt(x):
+    def compute_dx_dt(x: np.ndarray) -> np.ndarray:
         dx0dt = a * (x[1] - x[0])
         dx1dt = x[0] * (b - x[2]) - x[1]
         dx2dt = x[0] * x[1] - c * x[2]
@@ -53,35 +50,3 @@ def generate_lorenz(
 
     x_sim = np.stack(x_lst)
     return x_sim
-
-
-@click.command()
-@click.option("-o", "--output")
-def main(output):
-    """Run a test example."""
-    print("Simulation of the lorenz equation.")
-    lorenz = generate_lorenz()
-    print(lorenz.shape)
-    # plt.plot(lorenz[:, 0])
-    # plt.show()
-
-    os.environ["DISPLAY"] = ":1"
-    import matplotlib.pyplot as plt
-
-    if output is None:
-        import matplotlib
-
-        matplotlib.use("Qt5Agg")
-
-    print("Backend", plt.get_backend())
-    fig = plt.figure()
-    ax = fig.add_subplot(111, projection="3d")
-    ax.plot(lorenz[:, 0], lorenz[:, 1], lorenz[:, 2])
-    if output is None:
-        plt.show()
-    else:
-        plt.savefig(output)
-
-
-if __name__ == "__main__":
-    main()
