@@ -1,6 +1,6 @@
 """Version information for :mod:`jwt`.
 
-Run with ``python -m jwt.version``
+Run with ``python -m jaxwt.version``
 """
 
 import os
@@ -12,11 +12,11 @@ __all__ = [
     "get_git_hash",
 ]
 
-VERSION = "0.0.3"
+VERSION = "0.0.6"
 
 
 def get_git_hash() -> str:
-    """Get the :mod:`jwt` git hash."""
+    """Get the :mod:`jaxwt` git hash."""
     with open(os.devnull, "w") as devnull:
         try:
             ret = check_output(  # noqa: S603,S607
@@ -30,8 +30,8 @@ def get_git_hash() -> str:
             return ret.strip().decode("utf-8")[:8]
 
 
-def get_version(with_git_hash: bool = False):
-    """Get the :mod:`jwt` version string, including a git hash."""
+def get_version(with_git_hash: bool = False) -> str:
+    """Get the :mod:`jaxwt` version string, including a git hash."""
     return f"{VERSION}-{get_git_hash()}" if with_git_hash else VERSION
 
 
